#install.packages(c('foreign','pBrackets','Hmisc'))

rm(list=ls())
library(foreign)
library(pBrackets)

setwd("~/replication")

#Function for Creating Effect Size Plots
plot.effect <- function(data,labels,lab="",horizontal=TRUE,zero=TRUE,anyci=TRUE,ci2=FALSE,ci2.data=NULL,labsize=1.5,srt=45,psize=8,pch=19,col="red",bounds=NA,noxaxis=F){
	
if(horizontal==TRUE){
op <- par()
par(mar = op$mar + c(4,4,0,0),las=1,cex.axis=labsize, cex.lab=labsize)
n<-nrow(data)
rule <- n:1
if(anyci==TRUE){
if(zero){
xmin<-(-max(abs(data[,2:3])))
xmax<-max(abs(data[,2:3]))
outside <- (data[,2] > 0 | data[,3]<0)
}else{
xmin<-min(min(data[,2:3]),0)
xmax<-max(max(data[,2:3]),0)
outside <- FALSE
}
}else{
	if(zero){
	xmin<-(-max(abs(data[,1])))
	xmax<-max(abs(data[,1]))
	}else{
	xmin<-min(min(data[,1]),0)
	xmax<-max(max(data[,1]),0)
}
}	
	
	
if(noxaxis==F){	
plot(data[,1], rule, ylim=c(0.5,n+.75),xlim=c(xmin+.2*xmin,xmax+.2*xmax),xlab="", ylab="",yaxt="n", col=col, lwd=psize, pch=pch)
}else{
plot(data[,1], rule, ylim=c(0.5,n+.75),xlim=c(xmin+.2*xmin,xmax+.2*xmax),xlab="", ylab="",yaxt="n", col=col, lwd=psize, pch=pch,xaxt="n")
}

abline(h=1, lty=3, col="lightgray")
abline(h=2, lty=3, col="lightgray")
abline(h=3, lty=3, col="lightgray")
abline(v=0, lty=3)

if(anyci==TRUE){
if(ci2==TRUE){

segments(ci2.data[,1],rule,ci2.data[,2],rule, col="red", lwd=6)
segments(data[,2],rule,data[,3],rule, col=col, lwd=2)

}else{

segments(data[,2],rule,data[,3],rule, col=col, lwd=4)

}
}

axis(side=2, at=rule, labels=labels, las=1, lwd=0)
text(x=.9*(par("usr")[2]-par("usr")[1])/2,y=par("usr")[3] - 0.35*labsize,lab,xpd=TRUE,cex=labsize)
}else{
	labels<-rev(labels)
data<-data[nrow(data):1,]
n<-nrow(data)
rule <- n:1
if(anyci==TRUE){
if(zero){
xmin<-(-max(abs(data[,2:3])))
xmax<-max(abs(data[,2:3]))
outside <- (data[,2] > 0 | data[,3]<0)
}else{
xmin<-min(min(data[,2:3]),0)
xmax<-max(max(data[,2:3]),0)
outside <- FALSE
}
}else{
	if(zero){
	xmin<-(-max(abs(data[,1])))
	xmax<-max(abs(data[,1]))
	}else{
	xmin<-min(min(data[,1]),0)
	xmax<-max(max(data[,1]),0)
}
}	

if(sum(!is.na(bounds))>0){
	
	if(!is.na(bounds[1])) xmin <- bounds[1]

	if(!is.na(bounds[2])) xmax <- bounds[2]
}

	
op <- par()
par(mar = op$mar + c(4,4,0,0),las=1,cex.axis=labsize, cex.lab=labsize)
plot(rule,data[,1], xlim=c(0.5,n+.75),ylim=c(xmin+.2*xmin,xmax+.2*xmax),xlab="", ylab="",xaxt="n", col=col, lwd=psize, pch=pch )
#if(zero) abline(v=0, lty=1)
abline(h=0, lty=3)

if(anyci==TRUE){
if(ci2==TRUE){
ci2.data<-ci2.data[nrow(ci2.data):1,]

segments(rule,data[,2],rule,data[,3], col=col, lwd=2)	
segments(rule,ci2.data[,1],rule,ci2.data[,2], col=col, lwd=6)
}else{
segments(rule,data[,2],rule,data[,3], col=col, lwd=4)
}
}

if(noxaxis==F){
axis(side=1, at=rule, labels=FALSE, las=1, lwd=1,tick=T)
text(x = rule-.1, par("usr")[3] - 0.15*xmax, labels = labels, srt = srt, pos = 1, xpd = TRUE,cex=labsize)
text(x=par("usr")[1]-.18*labsize*(par("usr")[2]-par("usr")[1]),y=(par("usr")[3]+par("usr")[4])/2,lab,srt=90,xpd=TRUE,cex=labsize)
}

}

}

#***FIGA8***
#Cross section Individual level plots

effects.files<-list.files("tables",pattern="(.*ind_cs)(.*sr2)(.*\\.csv$)")

estimates<-c()
for (file in effects.files) estimates[[file]]<-read.csv(file=paste("tables/",file,sep=""),stringsAsFactors=F,skip=1)[1:2,-1]
	
estimates2<-lapply(estimates,function(x) t(apply(x, 2,function(x) as.numeric(gsub("\\=|\\*|\\(|\\)","",x)))))

estimates3<-lapply(estimates2,function(x) data.frame(estimate=x[,1],lci=x[,1]-1.96*x[,2],uci=x[,1]+1.96*x[,2]))

estimates4<-do.call(rbind.data.frame, estimates3)
rm(estimates2,estimates3)


estimates4$year <- as.numeric(substr(rownames(estimates4),8,11))

estimates4$labs <- c("PVI", "PVI,\n State FEs","PVI,\n State FEs and Cov","Ex Post", "Ex Post,\n State FEs","Ex Post,\n State FEs and Cov")

estimates4$col<-sapply(as.numeric(estimates4$lci>0),function(x){
	if(x==1){
		return("red")
	}else{
		return("black")
	}
})

rownames(estimates4) <- 1:nrow(estimates4)

for (yr in seq(2008,2014,2)){

	data <- subset(estimates4, year == yr)
	labs <- data$labs
	
	#pdf(paste("figures/ind_cs_",yr,".pdf",sep=""))
	jpeg(paste("figures/ind_cs_",yr,".jpeg",sep=""),res=300,width = 8, height=6,units="in")
	
	plot.effect(1000*data[,1:3],labels=labs,lab="Turnout (%)",horizontal=F,zero=T,labsize=.75,bounds=c(-.75,3.75),col=rev(data$col))
	dev.off()
}

#***FIGA12***
#Time varying covariates

effects.files<-list.files("tables",pattern="(.*sr2)(.*tvcov|.*maj_min)(.*\\.csv$)")

estimates<-c()
for (file in effects.files) estimates[[file]]<-read.csv(file=paste("tables/",file,sep=""),stringsAsFactors=F,skip=1)[1:2,-1]
	
estimates2<-lapply(estimates,function(x) t(apply(x, 2,function(x) as.numeric(gsub("\\=|\\*|\\(|\\)","",x)))))

estimates3<-lapply(estimates2,function(x) data.frame(estimate=x[,1],lci=x[,1]-1.96*x[,2],uci=x[,1]+1.96*x[,2]))

estimates4<-do.call(rbind.data.frame, estimates3)

estimates5<-estimates4[grepl("(.*tvcov)(.*\\.4)",rownames(estimates4)),]
rm(estimates2,estimates3)

estimates5[grep("all",rownames(estimates5)),"year"] <- "All Years"
estimates5[grep("08_12",rownames(estimates5)),"year"] <- "2008 & 2012"
estimates5[grep("10_14",rownames(estimates5)),"year"] <- "2010 & 2014"


estimates5$labs <- c(rep("PVI",3),rep("Ex Post",3))

estimates5$col<-sapply(as.numeric(estimates5$lci>0),function(x){
	if(x==1){
		return("red")
	}else{
		return("black")
	}
})

rownames(estimates5) <- 1:nrow(estimates5)


#pdf("figures/ind_panel_tvcov.pdf")
jpeg("figures/ind_panel_tvcov.jpeg",res=300,width = 8, height=6,units="in")

plot.effect(1000*estimates5[,1:3],labels=paste(estimates5$labs,estimates5$year,sep=", "),lab="Turnout (%)",horizontal=F,zero=T,labsize=.75,bounds=c(-.75,3.75),col=rev(estimates5$col))
dev.off()


#***FIG4***
#Graph of pretrends
pre.trends <- read.dta("dta/user_created_dta/pre_trends_graphs.dta")
pre.trends <-subset(pre.trends,year<=2011)
names(pre.trends)[3]<-"voted"

attach(pre.trends)
#pdf("figures/pre_trends.pdf",width = 8, height=6)
jpeg("figures/pre_trends.jpeg",res=300,width = 8, height=6,units="in")

par(mar=c(5.1,4.1,1.1,1.1),las=1)

plot.line<-function(x,y,restriction,col,lside){
	points(x=x[treatment==restriction],y=y[treatment==restriction],pch=19,cex=.5,col=col)
	lines(x=x[treatment==restriction],y=y[treatment==restriction],lty=1,lwd=2,col=col)
	dist <- min(3,nchar(restriction)/6)
	if(lside %% 2 == 1){
		text(x=x[treatment==restriction][1]-dist,y=y[treatment==restriction][1],labels=restriction,cex=.65,col=col)
	} else {
		k<-length(x[treatment==restriction])
		print(k)
	text(x=x[treatment==restriction][k]+dist,y=y[treatment==restriction][k],labels=restriction,cex=.65,col=col)
}
}

plot(x=year[treatment=="Always Competitive"],
     y=voted[treatment=="Always Competitive"],
     ylab="Turnout (%)", xlab="Year",main="",
    xlim=c(1997,2015),ylim=c(.3,.6),type="n")

	type<-unique(treatment)
	color <- c("steelblue1","darkblue","red","darkred")
	
	for (i in 1:4) plot.line(year,voted,type[i],color[i],i)
abline(v=2011,lty=3,col="gray",lwd=1.5)

graphics.off()

detach(pre.trends)



#***FIG5***
#Graph of effect sizes

#Plot effects
#Data should be in form of 3 columns, w/ effect, lci, uci

effects.files<-list.files("tables",pattern="(.*bp_abs)(.*sr2)(.*\\.csv$)")
effects.files<-effects.files[-grep("mc|age|maj_min|match|tvcov|cook",effects.files)]

estimates<-c()
for (file in effects.files) estimates[[file]]<-read.csv(file=paste("tables/",file,sep=""),stringsAsFactors=F,skip=1)[1:2,-1]
	
estimates2<-lapply(estimates,function(x) t(apply(x, 2,function(x) as.numeric(gsub("\\=|\\*|\\(|\\)","",x)))))

estimates3<-lapply(estimates2,function(x) data.frame(estimate=x[,1],lci=x[,1]-1.96*x[,2],uci=x[,1]+1.96*x[,2]))

estimates4<-do.call(rbind.data.frame, estimates3)

rm(estimates2,estimates3)

labs<-c("All Years: \n State-Year FEs","All Years:\n State-Year FEs & Covariates","All Years: \n Diff-in-Diff","Pres. Election Years: \n State-Year FEs","Pres. Election Years: \n State-Year FEs & Covariates","Pres. Election Years: \n Diff-in-Diff","Mid-terms: \n State-Year FEs","Mid-terms: \n State-Year FEs & Covariates","Mid-term: \n Diff-in-Diff")

#Note: We multiply by factor of 2 for these past estimates because their effects are measured for gap between 1st #and 2nd place vote getter, so a 10 point shift for them is from 50-50 to 55-45;
#We use a PVI measure, which is the difference from 50; a 10 point shift for us is 50-50 to 60-40
#This is equivalent to a 20 point shift for these past estimates.

blais.effect <- 20*data.frame(estimate=0.14,lci=.14-1.96*.06,uci=.14+1.96*.06)
#blais.effect <- 20*data.frame(estimate=0.14,lci=NA,uci=NA)

silberman.effect <-20*data.frame(estimate=0.2182,lci=.2182-1.96*.014,uci=.2182+1.96*.014)
#silberman.effect <-20*data.frame(estimate=0.2182,lci=NA,uci=NA)


#aggregate effects

agg.effects.files<-list.files("tables",pattern="(agg_pvi)(.*\\.csv$)")

agg.estimates<-c()
for (file in agg.effects.files) agg.estimates[[file]]<-read.csv(file=paste("tables/",file,sep=""),stringsAsFactors=F,skip=1)[1:2,-1]
	
agg.estimates2<-lapply(agg.estimates,function(x) t(apply(x, 2,function(x) as.numeric(gsub("\\=|\\*|\\(|\\)","",x)))))

agg.estimates3<-lapply(agg.estimates2,function(x) data.frame(estimate=x[,1],lci=x[,1]-1.96*x[,2],uci=x[,1]+1.96*x[,2]))

agg.estimates4<-do.call(rbind.data.frame, agg.estimates3)
agg.effect <- subset(agg.estimates4,grepl("\\.1",rownames(agg.estimates4)))


#District Turnout Characteristics
#Geys effect sizes
dld <- read.dta("dta/district_level_0814.dta")
dld<-dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$st_abbrev!="LA" & dld$year %in% c(2014),]

geys.effect0<-10/sd(dld$abs_pvi,na.rm=T)*(0.58*sd(dld$pct_turnout,na.rm=T))
geys.effect<-data.frame(estimate=geys.effect0,lci=NA,uci=NA)

#pdf("figures/ind_panel_effects.pdf",width = 8, height=6)
jpeg("figures/ind_panel_effects.jpeg",res=300,width = 8, height=6,units="in")


estimates.final <- rbind(blais.effect,silberman.effect,geys.effect,10*agg.effect,1000*estimates4[c(3,9,15),])


estimates.final$col<-sapply(as.numeric(estimates.final$lci>0),function(x){
	if(x==1 | is.na(x)){
		return("red")
	}else{
		return("black")
	}
})
	
plot.effect(estimates.final[,1:3],labels="",lab="Turnout (%)",horizontal=F,bounds=c(-1.2,6.5),noxaxis=T,psize=2,col=rev(estimates.final$col))

brackets(x1=3,x2=1,y1=-.55,y2=-.55,lwd = 1)
brackets(x1=7,x2=4,y1=-.55,y2=-.55,lwd = 1)
brackets(x1=10,x2=8,y1=-.55,y2=-.55,lwd = 1)
text(x = 2, y = -1.2, "Past Estimates", cex = .9)
text(x = 5.5, y = -1.2, "Aggregate Cross Sectional", cex = .9)
text(x = 9, y = -1.2, "Diff-in-Diff", cex = .9)

text(x=1.2,y=blais.effect[3]+.5,"Blais & Dobrznska 1998 \n (Cross-National)",cex=.65)
text(x=2.2,y=silberman.effect[2]-.4,"Silberman & Durden 1975 \n (U.S. Congress)",cex=.65)
text(x=3.2,y=geys.effect[1]-.4,"Geys 2006 \n (Meta-Analysis)",cex=.65)

text(x=4,y=10*agg.effect[1,2]-.3,"2008",cex=.65)
text(x=5,y=10*agg.effect[2,2]-.3,"2010",cex=.65)
text(x=6,y=10*agg.effect[3,2]-.3,"2012",cex=.65)
text(x=7,y=10*agg.effect[4,2]-.3,"2014",cex=.65)
text(x=8.2,y=1000*estimates4[3,3]+.3,"All Years",cex=.65)
text(x=9.2,y=1000*estimates4[9,3]+.5,"Presidential Years",cex=.65)
text(x=10.2,y=1000*estimates4[15,3]+.3,"Midterm Years",cex=.65)

graphics.off()

#***FIGA9***
#Matched Differences in Differences

estimates <- cbind(read.csv(file="tables/binary_treatment_did.csv",stringsAsFactors=F,skip=3)[1:2,2:5],read.csv(file="tables/binary_treatment_did.csv",stringsAsFactors=F,skip=3)[3:4,6:9])
estimates2 <- t(apply(estimates, 2,function(x) as.numeric(gsub("\\=|\\*|\\(|\\)","",x))))

create.ci <- function(x) data.frame(estimate=x[,1],lci=x[,1]-1.96*x[,2],uci=x[,1]+1.96*x[,2])

estimates3<-create.ci(estimates2)
estimates3$col<-sapply(as.numeric(estimates3$lci>0),function(x){
	if(x==1 | is.na(x)){
		return("red")
	}else{
		return("black")
	}
})
	
labs<-c("Midterms\nDID","Midterms\nDID Matched","Presidential Years\nDID","Presidential Years\nDID Matched","Midterms\nDID","Midterms\nDID Matched","Presidential Years\nDID","Presidential Years\nDID Matched")

	
#pdf("figures/did_effectsc.pdf",width = 8, height=6)
jpeg("figures/did_effectsc.jpeg",res=300,width = 8, height=6,units="in")

plot.effect(100*estimates3[,1:3],labels="",lab="Turnout (%)",horizontal=F,bounds=c(-4,4),noxaxis=T,psize=2,col=rev(estimates3$col))
brackets(x1=4,x2=1,y1=-1.6,y2=-1.6,lwd = 1)
text(x = 2.5, y = -2.25, "PVI Competitiveness", cex = .9)
brackets(x1=8,x2=5, y1=-1.6, y2=-1.6,lwd = 1)
text(x = 6.5, y = -2.25, "Ex Post Competitiveness", cex = .9)


for (n in 1:length(labs)){
	if(n%%2!=0){
		text(x = n, y = 100*estimates3[n,3]+.4, labs[n], cex = .65)	
	}else{
		text(x = n, y = 100*estimates3[n,2]-.4, labs[n], cex = .65)
	}
} 

graphics.off()


#Marginal voters
#***FIG6***

estimates <- cbind(read.csv(file="tables/marginal_voters.csv",stringsAsFactors=F,skip=3)[1:2,c(2,4,6,8)],read.csv(file="tables/marginal_voters.csv",stringsAsFactors=F,skip=3)[3:4,c(3,5,7,9)])

estimates2 <- t(apply(estimates, 2,function(x) as.numeric(gsub("\\=|\\*|\\(|\\)","",x))))

create.ci <- function(x) data.frame(estimate=x[,1],lci=x[,1]-1.96*x[,2],uci=x[,1]+1.96*x[,2])

estimates3<-create.ci(estimates2)

estimates3$col<-sapply(as.numeric(estimates3$lci>0),function(x){
	if(x==1){
		return("red")
	}else{
		return("black")
	}
})

#pdf("figures/marginal_voters.pdf",width = 8, height=6)
jpeg("figures/marginal_voters.jpeg",res=300,width = 8, height=6,units="in")

plot.effect(1000*estimates3[,1:3],labels="",lab="Turnout (%)",horizontal=F,bounds=c(-1,4),noxaxis=T,psize=2,col=rev(estimates3$col))
brackets(x1=4,x2=1,y1=-.2,y2=-.2,lwd = 1)
text(x = 2.5, y = -.9, "PVI Competitiveness", cex = .9)
brackets(x1=8,x2=5, y1=-.2, y2=-.2,lwd = 1)
text(x = 6.5, y = -.9, "Ex Post Competitiveness", cex = .9)

labs<-rep(c("Voted Once\nin 2006--2008","Top Quartile\nin Educ.","Top Quartile\nMedian HH Inc.","Registered\nD/R"),2)
	
for (n in 1:length(labs)){
		text(x = n, y = 1000*estimates3[n,3]+.3, labs[n], cex = .65)	
} 

graphics.off()


#Balance Plots

#***FIGA10***
#***FIGA11***

balance.files<-list.files("tables",pattern="(matchbalance)(.*\\.csv$)")

balance<-c()
for (file in balance.files) balance[[file]]<-read.csv(file=paste("tables/",file,sep=""),stringsAsFactors=F)[c(1,2,5,6),]

	flex.reshape <- function(x,treat) reshape(x,timevar=treat,idvar="matched",direction="wide")

mean.diff.std <- function(m1,m2,sd1,sd2,n1,n2) (m1-m2)/sqrt((sd1^2*n1+sd2^2*n2)/(n1+n2))

balance.std.mean<-lapply(balance,function(x){
	x<-flex.reshape(x,names(x)[1])
	variables <- gsub("\\.0|\\.1|\\_sd|\\N","",grep("\\.0",names(x),value=T))
	y<-data.frame(x$matched)
	for (row in 1:nrow(x)){
	for (item in variables){
		if(!(item %in% c("","close_abs_pvi","close_abs_vote_margin"))){
		y[row,item]<-mean.diff.std(x[row,paste(item,"1",sep=".")],x[row,paste(item,"0",sep=".")],x[row,paste(item,"_sd.1",sep="")],x[row,paste(item,"_sd.0",sep="")],x[row,"N.1"],x[row,"N.0"])	
		}
	}	
}
return(y)
}
)

extract.N <-c()

for (k in names(balance)) extract.N<-rbind(extract.N,data.frame(aggregate(N~matched,data=balance[[k]],FUN=sum),data=k))

balance.vars <- c("Voted 2006","Black","Hispanic","Female","Asian","Age 65+","Age","Education (BA+)","Registered Dem.")

balance.plot <- function(x,labs,treat,xlabel){
	require(Hmisc)
	names(x) <- c("Matched",labs)
	y0<-subset(x,Matched==0)[-1]
	y1<-subset(x,Matched==1)[-1]
	y0b<-sort(y0,decreasing=T)
	y1b<-y1[names(y0b)]
	bounds<-max(abs(rbind(y0b,y1b)),na.rm=T)+.4*max(abs(rbind(y0b,y1b)),na.rm=T)
	dotchart2(as.numeric(y0b),labels=names(y0b),pch=19,xlim=c(min(-.3,-bounds),max(.3,bounds)),col="red",xlab=xlabel,sort.=F)
	dotchart2(as.numeric(y1b),add=T,pch=22,sort.=F)
	abline(v=0)
}	

for (bplot in names(balance.std.mean)){
	name.out <- gsub("\\.csv","",bplot)

#pdf(paste("figures/",name.out,".pdf",sep=""),width = 8, height=6)
jpeg(paste("figures/",name.out,".jpeg",sep=""),res=300,width = 8, height=6,units="in")

	par(mar=c(5.1,4.1,1.1,1.1))
	balance.plot(balance.std.mean[[bplot]],labs=balance.vars,treat="x.matched",xlab="Standardized Mean Difference")
	graphics.off()
}

balance.t.test<-c()
for (bplot in names(balance.std.mean)){
balance.t.test[[bplot]]<-data.frame(x.matched=balance.std.mean[[bplot]][,1],(balance.std.mean[[bplot]][,-1])*sqrt(subset(extract.N,data==bplot)[,"N"]))
}


#T-Test figures -- Didn't make it into final paper
for (bplot in names(balance.t.test)){
	name.out <- gsub("\\.csv","",bplot)

#pdf(paste("figures/",name.out,"_ttest.pdf",sep=""),width = 8, height=6)
jpeg(paste("figures/",name.out,"_ttest.jpeg",sep=""),res=300,width = 8, height=6,units="in")

	par(mar=c(5.1,4.1,1.1,1.1))
	balance.plot(balance.t.test[[bplot]],labs=balance.vars,treat="x.matched",xlab="t-Statistic for Difference in Means")
	abline(v=-1.96,lwd=3,col="red",lty=3)
	abline(v=1.96,lwd=3,col="red",lty=3)
	graphics.off()
}

conversion.factor<-c()
for (bplot in names(balance.std.mean)){
conversion.factor[[bplot]]<-balance.t.test[[bplot]][1,2]/balance.std.mean[[bplot]][1,2]
}

for (bplot in names(balance.t.test)){
	name.out <- gsub("\\.csv","",bplot)

#pdf(paste("figures/",name.out,"_ttest2.pdf",sep=""),width = 8, height=6)
jpeg(paste("figures/",name.out,"_ttest2.jpeg",sep=""),res=300,width = 8, height=6,units="in")

	par(mar=c(5.1,4.1,3.1,1.1))
	balance.plot(balance.t.test[[bplot]],labs=balance.vars,treat="x.matched",xlab="")
	at2<- round(seq(from = -0.3, to = .3, by = .1),1)
	at3<-round(at2*conversion.factor[[bplot]])
	mtext("Std. Mean Difference",3,line=2,at=0,col="black",cex=.75)
	mtext("t-Test of Mean Diff.",1,line=2,at=0,col="black",cex=.75)
	axis(3,at=at3,labels=at2,cex.axis=.75)

	graphics.off()
}


