***********************************
***********************************
***** replication_agg.do *****
***********************************
***********************************

*****************************
*** set up the directory ***
****************************
clear 
set more 1
cd "~/replication"

*ssc install binscatter
**********************************************************
*** regressions of turnout on district competitiveness ***
**********************************************************
use "dta/district_level_0814.dta", clear

*** variable labels for regression tables ***
label var margin_of_victory "Ex Post Competitiveness"
label var abs_pvi "PVI Competitiveness"
label var pct_65plus "Age 65+ (\%)"
label var pct_female "Female (\%)"
label var pct_nh_black "Non-Hispanic Black (\%)"
label var pct_nh_asian "Non-Hispanic Asian (\%)"
label var pct_hispanic "Hispanic (\%)"
label var pct_ba_higher "BA or higher (\%)"
label var pct_hs_higher "HS or higher (\%)"
label var pct_emp_pop_25_64 "Employment-pop. ratio (\%)"
label var hh_med_inc_con13_thous "Median household income"
label var pop_density_thous "Population density"
label var pct_mobility "Residential mobility (\%)"

*** regression tables for 2008-2014 ***
***FIG5***
***TABA2***
***TABA3***
***TABA4***
***TABA5***

set more 1
foreach x in 2008 2010 2012 2014 {

eststo clear

local partial pct_65plus pct_hispanic pct_nh_black pct_nh_asian ///
			pct_hs_higher pct_ba_higher 
local controls pct_65plus pct_hispanic pct_nh_black pct_nh_asian ///
			pct_hs_higher pct_ba_higher pct_emp_pop_25_64 hh_med_inc_con13_thous ///
			pop_density_thous pct_mobility

* without controls, no state FEs
eststo: reg pct_turnout abs_pvi ///
	if uncontested==0 & twoDs_or_twoRs==0 & year==`x'
estadd local stfe "No"
estadd local part "No"
estadd local full "No"
* without controls, with state FEs
eststo: reg pct_turnout abs_pvi i.st_id ///
		if uncontested==0 & twoDs_or_twoRs==0 & year==`x'
estadd local styrfe "Yes"
estadd local part "No"
estadd local full "No"

* with partial controls, no state FEs
eststo: reg pct_turnout abs_pvi `partial' ///
	if uncontested==0 & twoDs_or_twoRs==0 & year==`x'
estadd local stfe "No"
estadd local part "Yes"
estadd local full "No"
* with partial controls, with state FEs
eststo: reg pct_turnout abs_pvi `partial' i.st_id ///
		if uncontested==0 & twoDs_or_twoRs==0 & year==`x'
estadd local stfe "Yes"
estadd local part "Yes"
estadd local full "No"

* with full controls, no state FEs
eststo: reg pct_turnout abs_pvi `controls' ///
	if uncontested==0 & twoDs_or_twoRs==0 & year==`x'
estadd local stfe "No"
estadd local part "No"
estadd local full "Yes"
* with full controls, with state FEs
eststo: reg pct_turnout abs_pvi `controls' i.st_id ///
		if uncontested==0 & twoDs_or_twoRs==0 & year==`x'
estadd local styrfe "Yes"
estadd local part "No"
estadd local full "Yes"

foreach ftype in "tex" "csv"{

esttab using "tables/agg_pvi_`x'.`ftype'", replace nonotes label ///
	title("Results Based on `x' House Elections" \label{agg-pvi-`x'}) ///
	scalars("styrfe State FEs" "part Parial Controls" "full Full Controls" "N Observations" "r2_a Adjusted $ R^2 $") ///
	b(3) se(3) nomtitles nogaps noobs keep(abs_pvi) sfmt(%9.3gc) ///
	addnotes("Standard errors in parentheses. * p $<$ 0.05, ** p $<$ 0.01, *** p $<$ 0.001" ///
			 "The sample is comprised of contested general elections by a D and R candidate." ///
			 "All elections in Louisiana are excluded from the sample due to their unusual rules." ///
			 "Partial control variables include share age 65+, share Hispanic, share non-Hispanic" ///
			 "Black, share non-Hispanic Asian, share HS or higher, share BA or higher, and" /// 
			 "employment-population ratio. Full control variables include all partial controls as" ///
			 "well as median household income, population density, and residential mobility." ///
			 "Due to the scaling of the outcome and explanatory variables, an estimated" ///
			 "coefficient of 0.1 implies a 1 percentage point increase in turnout for a 10-point" ///
			 "increase in competitiveness.")
}
}


***FIG1***

*** export data set to R for binned scatter ***
*** turnout vs. pvi competitiveness, 2010   ***
use "dta/district_level_0814.dta", clear

binscatter pct_turnout abs_pvi if year==2010 & uncontested==0 & twoDs_or_twoRs==0, gen(scatter_bin)
keep if year==2010 & uncontested==0 & twoDs_or_twoRs==0

bys scatter_bin: egen mean_turnout = mean(pct_turnout)
by scatter_bin: egen mean_pvi = mean(abs_pvi)
by scatter_bin: gen bin_n=_N
keep scatter_bin mean_turnout mean_pvi bin_n
by scatter_bin: keep if _n==1
drop if scatter_bin==.
saveold "dta/user_created_dta/data_for_binned_scatter_2010.dta", replace version(12)



**********************************************************
*** campaign expenditures vs. district competitiveness ***
**********************************************************
*** read in candidate campaign expenditure data
use dta/campaign_expenditures_1012.dta, clear

*** merge in competitiveness and district-level data
rename state st_abbrev
rename dist district
merge m:1 st_abbrev district year using "dta/district_level_0814.dta"
tab year if _merge==2
drop if _merge==2 /* our analysis is for election years 2010 & 2012 */
drop _merge

*** expenditure variables
replace tot_dis=subinstr(subinstr(tot_dis,"$","",.),",","",.)
destring tot_dis, gen(_exp)
bys st_abbrev district year: egen _tot_exp=total(_exp)
gen _log_ind_exp=ln(_exp+1)
gen _log_tot_exp=ln(_tot_exp)

*** identify observations to use in cross-sectional regressions
bys st_abbrev district year: gen touse_xsec=1 if _n==1 & uncontested==0 & twoDs_or_twoRs==0 & st_abbrev!="LA"

*** identify observations to use in panel fixed effects regressions:
*** incumbents running for reelection in 2012 involved in contested elections
*** between a D & R in both 2010 & 2012
* find incumbents in 2012
gen inc_2012 = 1 if inc==1 & year==2012
bys fec_id : egen tot_inc_2012 = total(inc_2012)
* find candidates who had contested elections in 2010 & 2012
gen uncont_two = 1 if uncontested==1 | twoDs_or_twoRs==1
bys fec_id: egen tot_uncont_two = total(uncont_two)
gen touse_pan=1 if tot_inc_2012==1 & tot_uncont_two==0 & st_abbrev!="LA"

*** create our incumbency variable
* treat incumbents from special elections as non-incumbents
gen inc_1_0 = 0 if !missing(inc)
replace inc_1_0 = 1 if inc==1

*********************************************
*** variable labels for regression tables ***
*********************************************
label var margin_of_victory "Ex Post Competitiveness"
label var abs_pvi "PVI Competitiveness"
label var inc_1_0 "Incumbency Status"


**********************************************************
*** regression of campaign spending on competitiveness ***
**********************************************************

***TABA11***
set more 1
eststo clear

eststo: reg _log_tot_exp abs_pvi if touse_xsec==1 & year==2010 
	estadd local cand_fe "No"
	estadd local yr_fe "No"
	
eststo: reg _log_tot_exp margin_of_victory if touse_xsec==1 & year==2010
	estadd local cand_fe "No"
	estadd local yr_fe "No"
	
eststo: reg _log_tot_exp abs_pvi if touse_xsec==1 & year==2012 
	estadd local cand_fe "No"
	estadd local yr_fe "No"
	
eststo: reg _log_tot_exp margin_of_victory if touse_xsec==1 & year==2012
	estadd local cand_fe "No"
	estadd local yr_fe "No"

preserve
keep if touse_pan==1
xtset idno year
eststo: xtreg _log_tot_exp abs_pvi inc_1_0 i.year if touse_pan==1, fe cluster(idno)
	estadd local cand_fe "Yes"
	estadd local yr_fe "Yes"
	
eststo: xtreg _log_tot_exp margin_of_victory inc_1_0 i.year if touse_pan==1, fe cluster(idno)
	estadd local cand_fe "Yes"
	estadd local yr_fe "Yes"

esttab using "tables/spending_closeness_20102012.tex", replace nonotes label  ///
	title("Log Campaign Spending in 2010 and 2012 House Elections" \label{spending-2010}) ///
	scalars("cand_fe Candidate FEs" "yr_fe Year FEs") b(3) se(3)  ar2 nomtitles nogaps ///
	keep(abs_pvi margin_of_victory inc_1_0 _cons) ///
	mgroups("2010" "2012" "Fixed Effects", pattern(1 0 1 0 1 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	addnotes("Standard errors in parentheses (clustered by candidate for the fixed effects specifications)." ///
			 "* p $<$ 0.05, ** p $<$ 0.01, *** p $<$ 0.001" ///
			 "The dependent variable is the log of campaign spending by the two major-party candidates." ///
			 "For the 2010 and 2012 specifications, the sample is comprised of contested general" ///
			 "elections by a D and R candidate. For the fixed effects specification, the sample is" ///
			 "comprised of candidates elected in 2010 who sought re-election in 2012. For all" ///
			 "specifications, all elections in Louisiana are excluded.") 		 
restore

*** export data for binned scatter plot ***
* campaign spending vs. PVI competitiveness

***FIG7***

preserve
binscatter _log_tot_exp abs_pvi if touse_xsec==1 & year==2010, gen(scatter_bin) nq(14)
keep if touse_xsec==1 & year==2010
bys scatter_bin: egen mean_log_exp = mean(_log_tot_exp)
by scatter_bin: egen mean_pvi = mean(abs_pvi)
by scatter_bin: gen bin_n=_N
keep scatter_bin mean_log_exp mean_pvi bin_n
by scatter_bin: keep if _n==1
drop if scatter_bin==.
saveold "dta/user_created_dta/spending_binned_scatter.dta", replace version(12)
restore
* export the full data for the scatterplot 

***FIGA17***
preserve
keep if touse_xsec==1
saveold "dta/user_created_dta/district_expenditures.dta", replace version(12)
restore 

*** prep for merge with 2012 Wesleyan Media Project data
split name, p(",") gen(_name)
rename _name1 last_name
keep if year==2012

tempfile temp_expenditures
save `temp_expenditures'

**************************************************
*** spending, tv advertisements, and closeness ***
**************************************************
*** wesleyan media project data ***
use "dta/wmp-house-2012-v1.1.dta", clear

* drop a bunch of the content variables from WMD data that we don't need for 
* this analysis to reduce file size
drop phone website mail twitter youtube approve vid f_mention f_picture ///
f_narrate o_mention o_picture narrate cnt_prp cnt_fin ad_civ prty_mn ///
per_ply flag prsment gbush reagan gophse demhse gopsen demsen congmt democrats ///
republicans cite1 cite2 cite3 cite4 cite5 cite90 cite90txt op_media endorse1 ///
endorse2 endorse3 endorse4 endorse5 endorse6 endorse90 endorse90txt fear ///
enthusiasm anger pride humor sadness music0 music1 music2 music3 music90 ///
music90_txt mention* issue* 
* only keep candidate sponsored ads in the general election
keep if sponsor==1 
compress

*** fix errors in the data
* devin nunes should be CA-22
replace district = "22" if district=="21" & state=="CA" & sponsorcmag=="NUNES, DEVIN"
* betty sutton should be OH-16
replace district = "16" if district=="13" & state=="OH" & sponsorcmag=="SUTTON, BETTY"
* kathy hochul should be NY-27
replace district="27" if district=="26" & state=="NY" & sponsorcmag=="HOCHUL, KATHY"
* fix name issues in the sponsor variable so they're consistent across ads
replace sponsorcmag="FULLER-KENDALL, VIRGINIA" if sponsorcmag=="FULLER, VIRGINIA"
replace sponsorcmag="SCHULTZ, DEBBIE WASSERMAN" if sponsorcmag=="WASSERMAN-SCHULTZ, DEBBIE"
replace sponsorcmag="SWIHART, JACKIE WALORSKI" if sponsorcmag=="WALORSKI, JACKIE"
replace sponsorcmag="HENSLEY, TERESA" if sponsorcmag=="HENESLEY, TERESA"
replace sponsorcmag="GRISHAM, MICHELLE" if sponsorcmag=="LUJAN-GRISHAM, MICHELLE"
replace sponsorcmag="WAMP, WESTON" if sponsorcmag=="WESTON, WAMP"
replace sponsorcmag="BEUTLER, JAIME HERRERA" if sponsorcmag=="HERRERA-BEUTLER, JAIME"
replace sponsorcmag="RODGERS, CATHY MCMORRIS" if sponsorcmag=="MCMORRIS-RODGERS, CATHY"
replace sponsorcmag="RODGERS, CATHY MCMORRIS" if sponsorcmag=="RODGERS, CATHY"
replace sponsorcmag="MAFFEI, DAN" if sponsorcmag=="MAFFEI, DAN & DEMOCRATIC CONGRESSIONAL CAMPAI"

* collapse the data by candidate
bys state district sponsorcmag: gen ads_count = _N
by state district sponsorcmag: egen ads_cost = total(est_cost)
bys state district sponsorcmag creative: gen unique_ad = 1 if _n==1
by state district sponsorcmag: egen ads_unique = total(unique_ad)
drop unique_ad
by state district sponsorcmag: keep if _n==1

* prepare the name variable
split sponsorcmag, p(",") gen(name)
replace name1=trim(name1)
rename name1 last_name
drop name2 name3

* check for duplicates
duplicates report state district last_name

*** prep for merge
keep state district sponsorcmag last_name ads_*
rename state st_abbrev
destring district, replace
gen year = 2012

*** merge in campaign expenditures data
merge 1:1 year st_abbrev district last_name using `temp_expenditures', gen(_merge_tv)
drop if _merge_tv==1 /* only keeping general election candidates */
foreach var of varlist ads_* {
	replace `var' = 0 if missing(`var')
}

*** tv ads variables
bys st_abbrev district year: egen _tot_ads_cost=total(ads_cost)
by st_abbrev district year: egen _tot_ads_count=total(ads_count)
by st_abbrev district year: egen _tot_ads_unique=total(ads_unique)

gen _log_ind_ad=ln(ads_cost+1)
gen _log_tot_ad=ln(_tot_ads_cost+1)
gen share_ind_ad = ads_cost / _exp
gen share_tot_ad = _tot_ads_cost / _tot_exp

*** tv ads regressions ***
***TABA12***
set more 1
eststo clear

eststo: reg share_tot_ad abs_pvi if touse_xsec==1
eststo: reg share_tot_ad margin_of_victory if touse_xsec==1
eststo: reg _tot_ads_count abs_pvi if touse_xsec==1
eststo: reg _tot_ads_count margin_of_victory if touse_xsec==1
eststo: reg _tot_ads_unique abs_pvi if touse_xsec==1
eststo: reg _tot_ads_unique margin_of_victory if touse_xsec==1

esttab using "tables/tv_expenditures.tex", replace nonotes label  ///
	title("Television Advertising in 2012 House Elections" \label{tv-expenditures}) ///
	b(3) se(3)  ar2 nomtitles nogaps  ///
	mgroups("TV as Share of Exp." "Number of Ads" "Unique Ads", pattern(1 0 1 0 1 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	addnotes("Standard errors in parentheses. * p $<$ 0.05, ** p $<$ 0.01, *** p $<$ 0.001" ///
			 "The three dependent variables are: expenditures on television advertisements as a share of" ///
			 "total campaign expenditures, the number of television ads aired throughout the campaign," ///
			 "and the number of unique ads aired. The sample is comprised of contested general" ///
			 "elections by a D and R candidate. All elections in Louisiana are excluded from the sample" ///
			 "due to their unusual rules.")

*** export data for binned scatter plots
* ad spending as share of total expenditures vs PVI
***FIG8***

preserve
binscatter share_tot_ad abs_pvi if touse_xsec==1 & year==2012, gen(scatter_bin) nq(14)
keep if touse_xsec==1 & year==2012

bys scatter_bin: egen mean_share = mean(share_tot_ad)
by scatter_bin: egen mean_pvi = mean(abs_pvi)
by scatter_bin: gen bin_n=_N
keep scatter_bin mean_share mean_pvi bin_n
by scatter_bin: keep if _n==1
drop if scatter_bin==.
saveold "dta/user_created_dta/share_tv_pvi_binned_scatter.dta", replace version(12)
restore

***FIGA18***
***FIGA19***
* ad spending as share of total expenditures vs ex post competitiveness
preserve
binscatter share_tot_ad margin_of_victory if touse_xsec==1 & year==2012, gen(scatter_bin) nq(14)
keep if touse_xsec==1 & year==2012

bys scatter_bin: egen mean_share = mean(share_tot_ad)
by scatter_bin: egen mean_margin = mean(margin_of_victory)
by scatter_bin: gen bin_n=_N
keep scatter_bin mean_share mean_margin bin_n
by scatter_bin: keep if _n==1
drop if scatter_bin==.
saveold "dta/user_created_dta/share_tv_margin_binned_scatter.dta", replace version(12)
restore

* save a version of district data set with the tv and spending data for scatterplot
keep if touse_xsec==1
saveold "dta/user_created_dta/district_tv.dta", replace version(12)



*************************************
*** CCES panel 2010-2014 analysis ***
*************************************
*** read in the cces data
use "dta/CCES_Panel_Full3waves_VV_V3.dta", clear

*** identify if respondent is moving by examining state and district ***
* are they in the same state for 2010-14?
gen _same_state=0
replace _same_state=1 if inputstate_10==inputstate_post_10 & ///
	inputstate_10==inputstate_12 & inputstate_10==inputstate_post_12 & ///
	inputstate_10==inputstate_14 & inputstate_10==inputstate_post_14

* clean up district codings
destring cdid*, replace
replace cdid112_10 = 1 if cdid112_10==0 /* re-code at-large =1 for 2010 variables*/
replace cdid112_post_10 = 1 if cdid112_post_10==0

* same district within redistricting cycles
gen _same_dist=0
replace _same_dist=1 if cdid112_10==cdid112_post_10 & ///
	cdid112_10==cdid112_12 & cdid112_10==cdid112_post_12 & ///
	cdid113_12==cdid113_post_12 & ///
	cdid113_12==cdid114_14 & cdid113_12==cdid114_post_14

*** restrict to non-movers
keep if _same_state==1 & _same_dist==1
* 1,712 observations deleted

*** rename district variables for later reshaping (transposing) of data
gen _cd_10=cdid112_10
gen _cd_12=cdid113_12
gen _cd_14=cdid114_14

*** contacted by campaign
foreach x in 10 12 14 {
* any contact
gen _any_contact_`x'=1 if CC`x'_425a==1
replace _any_contact_`x'=0 if CC`x'_425a==2
* in person
gen _inperson_contact_`x'=0 if !missing(_any_contact_`x')
replace _inperson_contact_`x'=1 if CC`x'_425b_1==1
* phone
gen _phone_contact_`x'=0 if !missing(_any_contact_`x')
replace _phone_contact_`x'=1 if CC`x'_425b_2==1
* email or text
gen _emailtext_contact_`x'=0 if !missing(_any_contact_`x')
replace _emailtext_contact_`x'=1 if CC`x'_425b_3==1
* postcard or mail
gen _mail_contact_`x'=0 if !missing(_any_contact_`x')
replace _mail_contact_`x'=1 if CC`x'_425b_4==1

gen _methods_of_contact_`x' = 0 if !missing(_any_contact_`x')
foreach var of varlist CC`x'_425b_1 CC`x'_425b_2 CC`x'_425b_3 CC`x'_425b_4 {
	replace _methods_of_contact_`x' = _methods_of_contact_`x' + 1 if `var'==1
}
}

*** variables for roll off
gen _sen_vote_10 = 1 if inlist(CC10_410b,1,2,3,4)
replace _sen_vote_10 = 0 if inlist(CC10_410b,5)
gen _gov_vote_10 = 1 if inlist(CC10_411,1,2,3,4,7)
replace _gov_vote_10 = 0 if inlist(CC10_411,8)
gen _house_vote_10 = 1 if inlist(CC10_412,1,2,3,7)
replace _house_vote_10 = 0 if inlist(CC10_412,8)

gen _rolloff_10 = 0 if !missing(_house_vote_10) & (!missing(_gov_vote_10) | !missing(_sen_vote_10))
replace _rolloff_10 = 1 if _house_vote_10==0 & (_gov_vote_10==1 | _sen_vote_10==1)

gen _sen_vote_14 = 1 if inlist(CC14_410b,1,2,3,4)
replace _sen_vote_14 = 0 if inlist(CC14_410b,5)
gen _gov_vote_14 = 1 if inlist(CC14_411,1,2,7)
replace _gov_vote_14 = 0 if inlist(CC14_411,8)
gen _house_vote_14 = 1 if inlist(CC14_412,1,2,3,7)
replace _house_vote_14 = 0 if inlist(CC14_412,8)

gen _rolloff_14 = 0 if !missing(_house_vote_14) & (!missing(_gov_vote_14) | !missing(_sen_vote_14))
replace _rolloff_14 = 1 if _house_vote_14==0 & (_gov_vote_14==1 | _sen_vote_14==1)

gen _vv_10 = 1 if inlist(VV_general_10,1,2,3,4)
gen _vv_14 = 1 if inlist(VV_general_14,1,2,3,4,5)

replace _rolloff_10 = . if _vv_10!=1 | _vv_14!=1
replace _rolloff_14 = . if _vv_10!=1 | _vv_14!=1
replace _rolloff_10 = . if missing(_rolloff_14)
replace _rolloff_14 = . if missing(_rolloff_10)


* merge in st abbreviations
gen st_fips = inputstate_10
tostring st_fips, replace
replace st_fips = "0" + st_fips if strlen(st_fips)==1
merge m:1 st_fips using "dta/st_abbrev_fips.dta"
drop if _merge==2
drop _merge

*** keep only necessary variables
rename caseid _caseid
keep _* st_abbrev weight 

*** ensure a full panel
drop if missing(_any_contact_10) | missing(_any_contact_14)

*** reshape from wide to long
reshape long _cd_ _any_contact_ _inperson_contact_ _phone_contact_ _mail_contact_ ///
_emailtext_contact_ _methods_of_contact_ _rolloff_, i(_caseid) j(year)
replace year = year + 2000
rename _cd_ district

* merge in competitiveness measures for 113th congress
merge m:1 st_abbrev district year using "dta/district_level_0814.dta", ///
	keepusing(st_abbrev district year abs_pvi margin_of_victory uncontested twoDs_or_twoRs)
drop if _merge==2
tab st_abbrev if _merge==1
drop if _merge==1
drop _merge


*** balanced panel
drop if year==2012
bys _caseid: egen _ever_uncontested = total(uncontested)
by _caseid: egen _ever_twoDsRs = total(twoDs_or_twoRs)
keep if _ever_uncontested==0 & _ever_twoDsRs==0 & st_abbrev!="LA"

*** create a state x year variable for state-year FEs
egen st_yr = group(st_abbrev year)

*** create cluster variable based on district in 2010 and district in 2014
gen dist_10=district if year==2010
bys _caseid (year): replace dist_10=district[_n-1] if year==2014
gen dist_14=district if year==2014
bys _caseid (year): replace dist_14=district[_n+1] if year==2010
egen cluster_dist=group(st_abbrev dist_10 dist_14)

* set up the weights
xtset, clear
xtset _caseid year

*** variable labels for regression tables ***
label var margin_of_victory "Ex Post Competitiveness"
label var abs_pvi "PVI Competitiveness"

local cluster_var cluster_dist

set more 1
eststo clear
foreach var of varlist abs_pvi margin_of_victory {

	eststo: xtreg _any_contact `var' i.st_yr [pw=weight], fe cluster(`cluster_var')
	estadd local indfe "Yes"
	estadd local styrfe "Yes"
}

foreach var of varlist abs_pvi margin_of_victory {

	eststo: xtreg _inperson_contact_ `var' i.st_yr [pw=weight], fe cluster(`cluster_var')
	estadd local indfe "Yes"
	estadd local styrfe "Yes"
}

foreach var of varlist abs_pvi margin_of_victory {

	eststo: xtreg _phone_contact_ `var' i.st_yr [pw=weight], fe cluster(`cluster_var')
	estadd local indfe "Yes"
	estadd local styrfe "Yes"
}

foreach var of varlist abs_pvi margin_of_victory {

	eststo: xtreg _emailtext_contact_ `var' i.st_yr [pw=weight], fe cluster(`cluster_var')
	estadd local indfe "Yes"
	estadd local styrfe "Yes"
}

foreach var of varlist abs_pvi margin_of_victory {

	eststo: xtreg _mail_contact_ `var' i.st_yr [pw=weight], fe cluster(`cluster_var')
	estadd local indfe "Yes"
	estadd local styrfe "Yes"
}


***FIG9***
***TABA13***
esttab using "tables/cces_contact_all.tex", replace nonotes label ///
	title("Reported Campaign Contact" \label{cces-all}) ///
	scalars("indfe Individual FEs" "styrfe State-Year FEs") b(4) se(4) r2  nomtitles nogaps ///
	keep(abs_pvi margin_of_victory) ///
	mgroups("Any Contact" "In-Person" "Phone" "Text/Email" "Mail/Postcard", pattern(1 0 1 0 1 0 1 0 1 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	substitute({table} {sidewaystable}) ///
	addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses. * p $<$ 0.05, ** p $<$ 0.01, *** p $<$ 0.001" ///
			 "The dependent variable is coded =1 if the respondent reported campaign contact. The sample is based on respondents to the" ///
			 "CCES 2010-2014 panel and is restricted to individuals in contested general elections by a D and R candidate. All Louisiana" ///
			 "residents are excluded from the sample due to their unusual rules.")
esttab using "tables/cces_contact_all.txt", replace nonotes ci(6) nopar nostar ///
	keep(abs_pvi margin_of_victory) tab


*** roll off analysis ***
***TABA9***
set more 1
eststo clear
foreach var of varlist abs_pvi margin_of_victory {

	eststo: xtreg _rolloff_ `var' [pw=weight], fe cluster(`cluster_var')
	estadd local indfe "Yes"
	estadd local styrfe "No"
	
	eststo: xtreg _rolloff_ `var' i.st_yr [pw=weight], fe cluster(`cluster_var')
	estadd local indfe "Yes"
	estadd local styrfe "Yes"
}

esttab using "tables/cces_rolloff.tex", replace nonotes label ///
	title("Roll Off" \label{cces-rolloff}) ///
	scalars("indfe Individual FEs" "styrfe State-Year FEs") b(4) se(4) r2  nomtitles nogaps ///
	keep(abs_pvi margin_of_victory) ///
	addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses." ///
			 "* p $<$ 0.05, ** p $<$ 0.01, *** p $<$ 0.001" ///
			 "The dependent variable is coded =1 if the respondent reported voting in a" ///
			 "Senate or governor race but not a House race. The sample is based on respondents" ///
			 "to the CCES 2010-2014 panel and is restricted to validated voters in contested" ///
			 "general elections by a D and R candidate. All Louisiana residents are excluded" ///
			 "from the sample due to their unusual rules.") 
esttab using "tables/cces_rolloff.txt", replace nonotes ci(6) nopar nostar ///
	keep(abs_pvi margin_of_victory) tab



***********************************************
*** pew survey on perceived competitiveness ***
***********************************************
*** read in the pew data
use "dta/pew_competitive_survey.dta", clear

*** merge in competitiveness measures
* use their district codings
tostring cd, gen(district)
replace district = substr(district,2,2) if strlen(district)==3
replace district = substr(district,3,2) if strlen(district)==4
destring district, replace
* prepare the state variable
decode stalpha1, gen(st_abbrev)

merge m:1 st_abbrev district using dta/district_pvi_06.dta

* exclude Lousiana from sample due to unusual rules so re-code pvi values =.
replace abs_pvi=. if st_abbrev=="LA"
replace margin_of_victory=. if st_abbrev=="LA"

* think election will be close coded =1, heavily favored and don't know coded =0
gen think_close = 0 if inlist(q20,1,2,3)
replace think_close = 1 if q20==2

* education
gen _educ = 0 if inlist(educ,1,2)
replace _educ = 1 if inlist(educ,3,4,5)
replace _educ = 2 if inlist(educ,6,7)

* income 
gen _inc_cat = 0 if inlist(income,1,2,3)
replace _inc_cat = 1 if inlist(income,4,5)
replace _inc_cat = 2 if inlist(income,6)
replace _inc_cat = 3 if inlist(income,7)
replace _inc_cat = 4 if inlist(income,8)
replace _inc_cat = 5 if inlist(income,9)

* political knowledge
gen _pol_know = 0 if inlist(q25,2,3)
replace _pol_know = 0.5 if q25==1
replace _pol_know = _pol_know + 0.5 if q26==1

*** regressions
label var margin_of_victory "Closeness of Election"
label var abs_pvi "PVI Competitiveness"

*** cluster at congressional district level
egen clust_dist = group(st_abbrev district)

* set up the sampling weights
svyset, clear
svyset psraid [pweight=weight]
eststo clear

*** perceptions of closeness for uncontested races
* voters equally likely to predict close race in contested vs. uncontested districts

***TAB5***

svy: tab think_close uncontested, col

eststo: reg think_close abs_pvi [pweight=weight] if ///
	uncontested==0 & twoDs_or_twoRs==0, cluster(clust_dist)
estadd local con "No"

eststo: reg think_close abs_pvi i._educ i._inc_cat i.racethn i.recage2 [pweight=weight] if ///
	uncontested==0 & twoDs_or_twoRs==0, cluster(clust_dist)
estadd local con "Yes"

eststo: reg think_close margin_of_victory [pweight=weight] if ///
	uncontested==0 & twoDs_or_twoRs==0, cluster(clust_dist)
estadd local con "No"

eststo: reg think_close margin_of_victory i._educ i._inc_cat i.racethn i.recage2 [pweight=weight] if ///
	uncontested==0 & twoDs_or_twoRs==0, cluster(clust_dist)
estadd local con "Yes"
			 
esttab using "tables/pew_reg.tex", replace nonotes label ///
	title("Voter Perceptions of Closeness for 2006 House Elections" \label{pew-reg}) ///
	scalars("con Controls" "N Observations" "r2_a Adjusted $ R^2 $") ///
	b(3) se(3) nomtitles nogaps noobs sfmt(%9.3gc) ///
	keep(abs_pvi margin_of_victory _cons) ///
	addnotes("Standard errors, clustered at the CD level, are in parentheses." ///
			 "* p $<$ 0.05, ** p $<$ 0.01, *** p $<$ 0.001" ///
			 "Results are based on Pew survey data collected in October of 2006. The" ///
			 "outcome variable is coded =1 if respondent perceives a close contest." ///
			 "Control variables include age, education, income, and race/ethnicity." ///
			 "Due to the scaling of the outcome and explanatory variables, an" ///
			 "estimated coefficient of 0.001 implies a 1 percentage point increase in" ///
			 "perceiving a race to be close for a 10-point increase in competitiveness." ///
			 "The sample is restricted to respondents residing in districts contested" ///
			 "by a D and R candidate. Respondents from Louisiana are excluded due to" ///
			 "their unusual rules.")

*** binned scatterplots
* save individual-level pew data for scatterplot
saveold dta/user_created_dta/pew_analysis.dta, replace v(12)		 


* binned scatter for perceived closeness vs pvi competitiveness
***FIGA15
preserve
binscatter  think_close abs_pvi [aw=weight] if uncontested==0 & twoDs_or_twoRs==0, nq(8) gen(scatter_bin)
gen wt_think_close=weight*think_close
gen wt_abs_pvi=weight*abs_pvi
bys scatter_bin: egen sum_think_close = total(wt_think_close)
by scatter_bin: egen sum_pvi = total(wt_abs_pvi)
by scatter_bin: egen sum_weights=total(weight)
gen mean_pvi=sum_pvi/sum_weights
gen mean_think_close=sum_think_close/sum_weights
by scatter_bin: gen bin_n=_N
keep scatter_bin mean_think_close mean_pvi bin_n sum_weights
by scatter_bin: keep if _n==1
drop if scatter_bin==.
saveold "dta/user_created_dta/perceived_close_pew_pvibin.dta", replace version(12)
restore

* binned scatter for perceived closeness vs ex post competitiveness
***FIGA16***

binscatter think_close margin_of_victory [aw=weight] if uncontested==0 & twoDs_or_twoRs==0, nq(8) gen(scatter_bin)
gen wt_think_close=weight*think_close
gen wt_margin=weight*margin_of_victory
bys scatter_bin: egen sum_think_close = total(wt_think_close)
by scatter_bin: egen sum_margin = total(wt_margin)
by scatter_bin: egen sum_weights=total(weight)
gen mean_think_close=sum_think_close/sum_weights
gen mean_margin=sum_margin/sum_weights
by scatter_bin: gen bin_n=_N
keep scatter_bin mean_think_close mean_margin bin_n sum_weights
by scatter_bin: keep if _n==1
drop if scatter_bin==.
saveold "dta/user_created_dta/perceived_close_pew_marginbin.dta", replace version(12)



********************************************************
*** change in district composition vs. change in PVI ***
********************************************************

*** abs_pvi for pre-redistricting districts
use "dta/district_level_0814.dta", clear
keep if year==2010
keep st_abbrev district abs_pvi
rename district cd111
rename abs_pvi abs_pvi_111
tempfile pvi_111
save `pvi_111'

*** abs_pvi for post-redistricting districts
use "dta/district_level_0814.dta", clear
keep if year==2012
keep st_abbrev district abs_pvi
rename district cd113
rename abs_pvi abs_pvi_113
tempfile pvi_113
save `pvi_113'


***FIGA14***

*** crosswalk from 113th congress to 111th congress
import delimited using "dta/cd113_cd111_crosswalk.csv", clear varn(1)

* drop the first row of data which is labels
drop if state=="FIPS state"

* clean up variables
destring cd113 cd111 pop10 afact, replace
rename stab st_abbrev
drop if st_abbrev=="DC" /* drop dc */
replace cd111=1 if cd111==0 /* at large districts should be coded =1 */
replace cd113=1 if cd113==0

* create a tempfile with the full data
tempfile full_data
save `full_data'

*** link district pairs that have 50% of same residents across redistricting ***
keep if afact > .5 & !missing(afact)

* merge in abs_pvi based on cd111 districts
merge m:1 st_abbrev cd111 using `pvi_111'
drop if _merge==2
drop _merge

merge 1:1 st_abbrev cd113 using `pvi_113'
drop if _merge==2
drop _merge

*** change in abs_PVI
gen change_abs_pvi=abs_pvi_113-abs_pvi_111

saveold dta/user_created_dta/graph_same_dist_comp.dta, v(12) replace


*** link districts across redistricting based on same incumbent ***
***FIGA13***

use dta/same_incumbent_10_12.dta, clear

rename state_10 st_abbrev
rename incumb_dist_10 cd111
rename incumb_dist_12 cd113

keep if missing(incumb_status)
keep st_abbrev cd111 cd113

tempfile same_incumb
save `same_incumb'


*** read back in the full district pairwise data
use `full_data', clear 

merge m:1 st_abbrev cd111 cd113 using `same_incumb'
keep if _merge==3
drop _merge

* merge in abs_pvi based on cd111 districts
merge m:1 st_abbrev cd111 using `pvi_111'
drop if _merge==2
drop _merge

merge m:1 st_abbrev cd113 using `pvi_113'
drop if _merge==2
drop _merge

*** change in abs_PVI
gen change_abs_pvi=abs_pvi_113-abs_pvi_111


saveold dta/user_created_dta/graph_same_incumb_comp.dta, v(12) replace
