#install.packages(c('foreign','effsize'))


rm(list=ls())
library(foreign)
# library(Matching)
library(effsize)

setwd("~/replication")

dld10.bin <- read.dta("dta/user_created_dta/data_for_binned_scatter_2010.dta")
dld <- read.dta("dta/district_level_0814.dta")
ind <- read.dta("dta/user_created_dta/panel_comp_histogram.dta")


### scatterplot of win margin vs. PVI
reg.wm.pvi <- lm((dld$dv[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$st_abbrev!="LA"]*100 - 50)
               ~ dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$st_abbrev!="LA","_pvi"])
summary(reg.wm.pvi)

#***FIGA1***

#pdf("figures/scatter_win_margin_pvi.pdf",width = 8, height=6)
jpeg("figures/scatter_win_margin_pvi.jpeg",res=300,units="in",width = 8, height=6)

par(las=1)
par(mar=c(5.1,5.1,1.1,1.1))
# empty plot
plot(1, type="n", xlab="", ylab="",main="", xlim=c(-50,50), ylim=c(-50,50),
     xaxt="n",yaxt="n")
# gridlines
for (i in seq(-50,50,25)){
  abline(v=i,lwd=.5,lty=3,col="gray68")
  abline(h=i,lwd=.5,lty=3,col="gray68")
}
# plot the data points
points(x=dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$st_abbrev!="LA","_pvi"],
      y=(dld$dv[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$st_abbrev!="LA"]*100 - 50),
      pch=19,cex=.75,lwd=1.5,col=adjustcolor("steelblue3",alpha.f=.5))
# add the axes
axis(1,at=seq(-50,50,25), labels=c("R+50","R+25","50/50","D+25","D+50"))
mtext("PVI",side=1,line=2.5,cex=1)
axis(2,at=seq(-50,50,25), labels=c("R+50","R+25","50/50","D+25","D+50"))
mtext("Win Margin",side=2,line=3.5,cex=1,las=3)
# plot the least-squares fit
abline(reg.wm.pvi,col="darkblue",lwd=3.5)
# plot the 45-degree line
points(x=seq(-55,55,1),y=seq(-55,55,1),pch=20,col="darkred",cex=1)
graphics.off()


#***FIG1***
### local means scatterplot of pct turnout vs. competitiveness, 2010
reg.line <- lm(dld$pct_turnout[(dld$year==2010) & dld$uncontested==0 & dld$twoDs_or_twoRs==0] 
               ~ dld$abs_pvi[(dld$year==2010)&dld$uncontested==0&dld$twoDs_or_twoRs==0])
#pdf("figures/scatter_turnout_pvi_10.pdf",width = 8, height=6)
jpeg("figures/scatter_turnout_pvi_10.jpeg",res=300,units="in",width = 8, height=6)

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
plot(x=dld10.bin$mean_pvi,y=dld10.bin$mean_turnout, pch=19,
     cex=dld10.bin$bin_n/10, col=adjustcolor("steelblue4",alpha.f=.8),
     main="",ylab="", xlab="", xaxt="n",xlim=c(-41,0),ylim=c(32,46))
# horizontal axis 
axis(1,at=seq(-40,0,10), labels=c("90/10","80/20","70/30","60/40","50/50"))
mtext("Turnout (%)",side=2,line=2.5,cex=1,las=3)
mtext("PVI Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Less Competitive                                  More Competitive" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
abline(reg.line,col="darkblue",lwd=3)
graphics.off()


### PVI: covariate balance plot of competitive vs. non-competitive districts
dld$pvi_dichot[!is.na(dld$abs_pvi)] <- 0
dld$pvi_dichot[dld$abs_pvi>=-10] <- 1
dld$pvi_dichot <- as.factor(dld$pvi_dichot)
# re-order the factor levels for the plot
dld$pvi_dichot <- factor(dld$pvi_dichot,levels(dld$pvi_dichot)[c(2,1)])

vars <- c("pct_65plus", "pct_hispanic", "pct_nh_black", "pct_nh_asian",
  "pct_hs_higher", "pct_ba_higher", "pct_emp_pop_25_64", "hh_med_inc_con13_thous",
  "pop_density_thous", "pct_mobility")
t.pvi <- rep(NA,length(vars))
for(i in 1:length(vars)){
  temp.t <- t.test(dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0,vars[i]] ~ 
                   dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0,"pvi_dichot"],
                   var.equal=T)
  t.pvi[i] <- temp.t$statistic
}
sorted.t.pvi <- sort(t.pvi)

std.dif.means.pvi <- rep(NA,length(vars))
for(i in 1:length(vars)){
  temp.d <- cohen.d(dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0,vars[i]] ~ 
                     dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0,"pvi_dichot"])
  std.dif.means.pvi[i] <- temp.d$estimate
}
names(std.dif.means.pvi) <- c("Age 65+ (%)","Hispanic (%)", "Non-Hispanic Black (%)", "Non-Hispanic Asian (%)",
                  "HS or higher (%)", "BA or higher (%)", "Employment-pop. ratio (%)", "Median household income",
                  "Population density", "Residential mobility (%)")
				  
#***FIG2***
#pdf("figures/balance_std_pvi10.pdf",width = 8, height=6)
jpeg("figures/balance_std_pvi10.jpeg",res=300,units="in",width = 8, height=6)

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
sorted.dif.means.pvi <- sort(std.dif.means.pvi)
dotchart(sorted.dif.means.pvi,labels=names(sorted.dif.means.pvi),pch=19,xlim=c(-.65,.65))
abline(v=0,lwd=1,col="black",lty=1)
mtext("Standardized Difference in Means",side=1,line=2.5,cex=1)
text(x=sorted.dif.means.pvi,y=1:10,pos=1,cex=.7,
     labels=paste0("t=",sprintf("%.1f",round(sorted.t.pvi,1))))
graphics.off()

#***FIGA7***
### quantile-quantile plots
names <- c("Age 65+ (%)","Hispanic (%)", "Non-Hispanic Black (%)", "Non-Hispanic Asian (%)",
  "HS or higher (%)", "BA or higher (%)", "Employment-pop. ratio (%)", "Median household income",
  "Population density", "Residential mobility (%)")

#pdf("figures/qq_pvi10_1.pdf",width = 8, height=12)
jpeg("figures/qq_pvi10_1.jpeg",res=300,units="in",width = 8, height=12)

par(mar=c(5.1,4.1,2.1,2.1))
par(mfrow=c(3,2))
par(las=1)
for(i in 1:6){
temp.max <- max(c(dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==0,vars[i]],
                  y=dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==1,vars[i]]), na.rm=T)
temp.min <- min(c(dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==0,vars[i]],
                  y=dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==1,vars[i]]), na.rm=T)
qqplot(x=dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==0,vars[i]],
       y=dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==1,vars[i]],
       xlab="Uncompetitive Districts",ylab="Competitive Districts",
       xlim=c(temp.min,temp.max),ylim=c(temp.min,temp.max),main=names[i])
abline(a=0,b=1,col="red",lwd=2)
}
graphics.off()

#***FIGA7***

#pdf("figures/qq_pvi10_2.pdf",width = 8, height=8)
jpeg("figures/qq_pvi10_2.jpeg",res=300,width = 8, height=8,units="in")

par(mar=c(5.1,4.1,2.1,2.1))
par(las=1)
par(mfrow=c(2,2))
for(i in 7:10){
  temp.max <- max(c(dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==0,vars[i]],
                    y=dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==1,vars[i]]), na.rm=T)
  temp.min <- min(c(dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==0,vars[i]],
                    y=dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==1,vars[i]]), na.rm=T)
  qqplot(x=dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==0,vars[i]],
         y=dld[dld$uncontested==0 & dld$twoDs_or_twoRs==0 & dld$pvi_dichot==1,vars[i]],
         xlab="Uncompetitive Districts",ylab="Competitive Districts",
         xlim=c(temp.min,temp.max),ylim=c(temp.min,temp.max),main=names[i])
  abline(a=0,b=1,col="red",lwd=2)
}
graphics.off()

##################################################################
### change in district population by change in competitiveness ###
##################################################################

#***FIGA13***

sd.comp <- read.dta("dta/user_created_dta/graph_same_dist_comp.dta")
si.comp <- read.dta("dta/user_created_dta/graph_same_incumb_comp.dta")
reg.si <- lm(change_abs_pvi ~ afact, data=si.comp)
reg.sd <- lm(change_abs_pvi ~ afact, data=sd.comp)
#pdf("figures/same_inc_pop_changes_vs_comp_changes.pdf",width = 8, height=6)
jpeg("figures/same_inc_pop_changes_vs_comp_changes.jpeg",res=300,width = 8, height=6,units="in")

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
plot(1, type="n", xlab="", ylab="",main="",
     xlim=c(0.1,1),ylim=c(-25,25), xaxt="n")
abline(h=0,lwd=1)
points(x=si.comp$afact,y=si.comp$change_abs_pvi,
       pch=19,cex=1,col=adjustcolor("steelblue4",alpha.f=.6))
abline(reg.si,col="darkblue",lwd=3)
axis(1,at=seq(0.1,1,.1), labels=c("10%","20%","30%","40%","50%","60%","70%","80%","90%","100%"))
mtext("Change in PVI Competitiveness",side=2,line=2.5,cex=1,las=3)
mtext("Residents in Same District Pre- and Post-Redistricting (%)",side=1,line=2.5,cex=1)
graphics.off()

#***FIGA14***

#pdf("figures/same_dist_pop_changes_vs_comp_changes.pdf",width = 8, height=6)
jpeg("figures/same_dist_pop_changes_vs_comp_changes.jpeg",res=300,units="in",width = 8, height=6)

par(las=1)
plot(1, type="n", xlab="", ylab="",main="",xlim=c(0.5,1),ylim=c(-12,12), xaxt="n")
abline(h=0,lwd=1)
points(x=sd.comp$afact,y=sd.comp$change_abs_pvi,
     pch=19,cex=1,col=adjustcolor("steelblue4",alpha.f=.6))
# horizontal axis 
axis(1,at=seq(0.5,1,.1), labels=c("50%","60%","70%","80%","90%","100%"))
mtext("Change in PVI Competitiveness",side=2,line=2.5,cex=1,las=3)
mtext("Residents in Same District Pre- and Post-Redistricting (%)",side=1,line=2.5,cex=1)
abline(reg.sd,col="darkblue",lwd=3)
graphics.off()

#***FIGA2***
### histogram of competitiveness in 2008-2014
#pdf("figures/hist_agg_pvi.pdf",width = 8, height=6)
jpeg("figures/hist_agg_pvi.jpeg",res=300,width = 8, height=6,units="in")

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
hist(dld$abs_pvi[dld$uncontested==0&dld$twoDs_or_twoRs==0],
     col="darkblue",border="steelblue4",main="",xaxt="n",
     xlim=c(-45,0),ylim=c(0,225),xlab="",ylab="",breaks=15)
# horizontal axis 
axis(1,at=seq(-40,0,10), labels=c("90/10","80/20","70/30","60/40","50/50"))
mtext("Frequency",side=2,line=2.5,cex=1,las=3)
mtext("PVI Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Less Competitive                                  More Competitive" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
graphics.off()

#***FIGA3***
## histogram of closeness, 2008-2014
#pdf("figures/hist_agg_closeness.pdf",width = 8, height=6)
jpeg("figures/hist_agg_closeness.jpeg",res=300,units="in",width = 8, height=6)

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
hist(dld$margin_of_victory[dld$uncontested==0&dld$twoDs_or_twoRs==0],
     col="darkblue",border="steelblue4",main="",xaxt="n",
     xlim=c(-50,0),ylim=c(0,225),xlab="",ylab="",breaks=25)
# horizontal axis 
axis(1,at=seq(-50,0,10), labels=c("100/0","90/10","80/20","70/30","60/40","50/50"))
mtext("Frequency",side=2,line=2.5,cex=1,las=3)
mtext("Ex Post Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Less Competitive                                  More Competitive" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
graphics.off()


#***FIG3***

### histograms of change in competitiveness at individual level
# change in PVI
#pdf("figures/hist_ind_pvi.pdf",width = 8, height=6)

jpeg("figures/hist_ind_pvi.jpeg",res=300,units="in",width = 8, height=6)

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
hist(ind$diff_pvi_10_12,
     col="darkblue",border="steelblue4",main="",xaxt="n",yaxt="n",
     xlim=c(-40,40),ylim=c(0,550000),xlab="",ylab="",breaks=50)
# horizontal axis 
axis(1,at=seq(-40,40,10))
axis(2,at=seq(0,550000,50000), labels=seq(0,550,50))
mtext("Frequency (in thousands)",side=2,line=3,cex=1,las=3)
mtext("Change in PVI Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Decreased Competitiveness                     Increased Competitiveness" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
graphics.off()

#***FIGA6***

# change in closeness for 10->12
#pdf("figures/hist_ind_closeness_10_12.pdf",width = 8, height=6)
jpeg("figures/hist_ind_closeness_10_12.jpeg",res=300,units="in",width = 8, height=6)

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
hist(ind$diff_vote_margin_10_12,
     col="darkblue",border="steelblue4",main="",xaxt="n",yaxt="n",
     xlim=c(-40,40),ylim=c(0,225000),xlab="",ylab="",breaks=40)
# horizontal axis 
axis(1,at=seq(-40,40,10))
axis(2,at=seq(0,225000,25000), labels=seq(0,225,25))
mtext("Frequency (in thousands)",side=2,line=3,cex=1,las=3)
mtext("Change in Ex Post Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Decreased Competitiveness                     Increased Competitiveness" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
graphics.off()

#***FIGA4***
# change in closeness for 10->14
#pdf("figures/hist_ind_closeness_10_14.pdf",width = 8, height=6)
jpeg("figures/hist_ind_closeness_10_14.jpeg",res=300,width = 8, height=6,units="in")

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
hist(ind$diff_vote_margin_10_14,
     col="darkblue",border="steelblue4",main="",xaxt="n",yaxt="n",
     xlim=c(-40,40),ylim=c(0,225000),xlab="",ylab="",breaks=40)
# horizontal axis 
axis(1,at=seq(-40,40,10))
axis(2,at=seq(0,225000,25000), labels=seq(0,225,25))
mtext("Frequency (in thousands)",side=2,line=3,cex=1,las=3)
mtext("Change in Ex Post Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Decreased Competitiveness                     Increased Competitiveness" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
graphics.off()

#***FIGA5***

# change in closeness for 08->12
#pdf("figures/hist_ind_closeness_08_12.pdf",width = 8, height=6)
jpeg("figures/hist_ind_closeness_08_12.jpeg",res=300,width = 8, height=6, units="in")

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
hist(ind$diff_vote_margin_08_12,
     col="darkblue",border="steelblue4",main="",xaxt="n",yaxt="n",
     xlim=c(-40,40),ylim=c(0,225000),xlab="",ylab="",breaks=40)
# horizontal axis 
axis(1,at=seq(-40,40,10))
axis(2,at=seq(0,225000,25000), labels=seq(0,225,25))
mtext("Frequency (in thousands)",side=2,line=3,cex=1,las=3)
mtext("Change in Ex Post Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Decreased Competitiveness                     Increased Competitiveness" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
graphics.off()

#***FIGA15***
### local means scatterplot of perceived closeness vs. PVI
pew <- read.dta("dta/user_created_dta/pew_analysis.dta",convert.factors=F)
perceipvi <- read.dta("dta/user_created_dta/perceived_close_pew_pvibin.dta")
reg.percpvi <- lm(100*think_close ~ abs_pvi, data=pew, subset=(uncontested==0 & twoDs_or_twoRs==0),
                  weights=weight)
#pdf("figures/scatter_perceivedclose_pvi.pdf",width = 8, height=6)
jpeg("figures/scatter_perceivedclose_pvi.jpeg",res=300,width = 8, height=6, units="in")

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
plot(x=perceipvi$mean_pvi,y=perceipvi$mean_think_close*100,
     pch=19,cex=perceipvi$sum_weights/600,col=adjustcolor("steelblue4",alpha.f=.8),
     main="",ylab="", xlab="",xaxt="n",xlim=c(-30,0),ylim=c(40,70))
# horizontal axis 
axis(1,at=seq(-30,0,10), labels=c("80/20","70/30","60/40","50/50"))
mtext("Share Perceive Close Contest (%)",side=2,line=2.5,cex=1,las=3)
mtext("PVI Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Less Competitive                                  More Competitive" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
abline(reg.percpvi,col="darkblue",lwd=3)
graphics.off()

### local means scatterplot of perceived closeness vs. electoral closeness
#***FIGA16***

perceimar <- read.dta("dta/user_created_dta/perceived_close_pew_marginbin.dta")
reg.percmar <- lm(100*think_close ~ margin_of_victory, data=pew, 
                  subset=(uncontested==0 & twoDs_or_twoRs==0),
                  weights=weight)
#pdf("figures/scatter_perceivedclose_margin.pdf",width = 8, height=6)
jpeg("figures/scatter_perceivedclose_margin.jpeg",res=300,width = 8, height=6, units="in")

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
plot(x=perceimar$mean_margin,y=perceimar$mean_think_close*100,
     pch=19,cex=perceimar$sum_weights/600,col=adjustcolor("steelblue4",alpha.f=.8),
     main="",ylab="", xlab="",xaxt="n",xlim=c(-30,0),ylim=c(40,70))
# horizontal axis 
axis(1,at=seq(-30,0,10), labels=c("80/20","70/30","60/40","50/50"))
mtext("Share Perceive Close Contest (%)",side=2,line=2.5,cex=1,las=3)
mtext("Ex Post Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Less Competitive                                  More Competitive" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
abline(reg.percmar,col="darkblue",lwd=3)
graphics.off()

#***FIGA17***
### campaign spending binned scatter
spend <- read.dta("dta/user_created_dta/spending_binned_scatter.dta")
dld.exp <- read.dta("dta/user_created_dta/district_expenditures.dta")

reg.line <- lm(dld.exp[dld.exp$year==2010,"_log_tot_exp"] 
               ~ dld.exp$abs_pvi[dld.exp$year==2010])
#pdf("figures/app_scatter_spending_10.pdf",width = 8, height=6)
jpeg("figures/app_scatter_spending_10.jpeg",res=300,units="in",width = 8, height=6)

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
plot(x=dld.exp$abs_pvi[dld.exp$year==2010],
     y=dld.exp[dld.exp$year==2010,"_log_tot_exp"],
     pch=19,cex=.5,ylab="", xlab="",
     col=adjustcolor("steelblue3",alpha.f=.5),main="",
     xaxt="n",yaxt="n",xlim=c(-41,0),ylim=c(12.3,16.6))
# draw an axis on the left 
axis(1,at=seq(-40,0,10), labels=c("90/10","80/20","70/30","60/40","50/50"))
axis(2,at=seq(12.5,16.5,.5))
mtext("Log Campaign Expenditures",side=2,line=3,cex=1,las=3)
mtext("PVI Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Less Competitive                                  More Competitive" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
points(x=spend$mean_pvi,y=spend$mean_log_exp,pch=19,cex=spend$bin_n/10,
       col=adjustcolor("steelblue4",alpha.f=.8))
abline(reg.line,col="darkblue",lwd=3)
lines(loess.smooth(y=dld.exp[dld.exp$year==2010,"_log_tot_exp"],
                   x=dld.exp$abs_pvi[dld.exp$year==2010],family="gaussian")
      ,col="darkred",lty=2,lwd=3)
graphics.off()

#***FIG7***
#pdf("figures/scatter_spending_10.pdf",width = 8, height=6)
jpeg("figures/scatter_spending_10.jpeg",res=300,units="in",width = 8, height=6)

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
plot(x=spend$mean_pvi,y=spend$mean_log_exp,
     pch=19,ylab="", xlab="",cex=spend$bin_n/10,
     col=adjustcolor("steelblue4",alpha.f=.8),main="",
     xaxt="n",xlim=c(-41,0),ylim=c(13,15.5))
abline(reg.line,col="darkblue",lwd=3)
lines(loess.smooth(y=dld.exp[dld.exp$year==2010,"_log_tot_exp"],
                   x=dld.exp$abs_pvi[dld.exp$year==2010],family="gaussian")
      ,col="darkred",lty=2,lwd=3)
# draw an axis on the left 
axis(1,at=seq(-40,0,10), labels=c("90/10","80/20","70/30","60/40","50/50"))
mtext("Log Campaign Expenditures",side=2,line=3,cex=1,las=3)
mtext("PVI Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Less Competitive                                  More Competitive" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
graphics.off()

### share of campaign expenditures on tv vs. PVI
#***FIGA18***
tv.pvi <- read.dta("dta/user_created_dta/share_tv_pvi_binned_scatter.dta")
dld.tv <- read.dta("dta/user_created_dta/district_tv.dta")

reg.line <- lm(dld.tv[dld.tv$year==2012,"share_tot_ad"]*100 
               ~ dld.tv$abs_pvi[dld.tv$year==2012])
#pdf("figures/app_scatter_tvshare_12.pdf",width = 8, height=6)
jpeg("figures/app_scatter_tvshare_12.jpeg",res=300,width = 8, height=6,units="in")

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
plot(x=dld.tv$abs_pvi[dld.tv$year==2012],
     y=dld.tv[dld.tv$year==2012,"share_tot_ad"]*100,pch=19,cex=.5,
     ylab="", xlab="",col=adjustcolor("steelblue3",alpha.f=.5),main="",
     xaxt="n",yaxt="n",xlim=c(-41,0),ylim=c(0,65))
# draw an axis on the left 
axis(1,at=seq(-40,0,10), labels=c("90/10","80/20","70/30","60/40","50/50"))
axis(2,at=seq(0,65,15))
mtext("TV Ads as Share of Campaign Expenditures (%)",side=2,line=3,cex=1,las=3)
mtext("PVI Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Less Competitive                                  More Competitive" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
points(x=tv.pvi$mean_pvi,y=tv.pvi$mean_share*100,pch=19,cex=tv.pvi$bin_n/10,col=adjustcolor("steelblue4",alpha.f=.8))
abline(reg.line,col="darkblue",lwd=3)
lines(loess.smooth(y=dld.tv[dld.tv$year==2012,"share_tot_ad"]*100,
                   x=dld.tv$abs_pvi[dld.tv$year==2012],family="gaussian")
      ,col="darkred",lty=2,lwd=3)
graphics.off()

#***FIGA19***
### share of campaign expenditures on tv vs. win margin
tv.mar <- read.dta("dta/user_created_dta/share_tv_margin_binned_scatter.dta")

reg.line <- lm(dld.tv[dld.tv$year==2012,"share_tot_ad"]*100 
               ~ dld.tv$margin_of_victory[dld.tv$year==2012])
			   
#pdf("figures/app_scatter_tvshare_mar_12.pdf",width = 8, height=6)
jpeg("figures/app_scatter_tvshare_mar_12.jpeg",res=300,width = 8, height=6, units="in")

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
# draw the loess
plot(x=dld.tv$margin_of_victory[dld.tv$year==2012],
     y=dld.tv[dld.tv$year==2012,"share_tot_ad"]*100,pch=19,cex=.5,
     ylab="", xlab="",col=adjustcolor("steelblue3",alpha.f=.5),main="",
     xaxt="n",yaxt="n",xlim=c(-41,0),ylim=c(0,65))
# draw an axis on the left 
axis(1,at=seq(-40,0,10), labels=c("90/10","80/20","70/30","60/40","50/50"))
axis(2,at=seq(0,90,15))
mtext("TV Ads as Share of Campaign Expenditures (%)",side=2,line=3,cex=1,las=3)
mtext("Ex Post Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Less Competitive                                  More Competitive" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
points(x=tv.mar$mean_margin,y=tv.mar$mean_share*100,pch=19,cex=tv.mar$bin_n/10,col=adjustcolor("steelblue4",alpha.f=.8))
abline(reg.line,col="darkblue",lwd=3)
lines(loess.smooth(y=dld.tv[dld.tv$year==2012,"share_tot_ad"]*100,
                   x=dld.tv$margin_of_victory[dld.tv$year==2012],family="gaussian"),
      col="darkred",lwd=3,lty=2)
graphics.off()


#***FIG8***
### combined plot for pvi and margin of victory vs. share tv
#pdf("figures/scatter_tvshare_pvimar12.pdf",width = 8, height=6)
jpeg("figures/scatter_tvshare_pvimar12.jpeg",res=300,width = 8, height=6, units="in")

par(mar=c(5.1,4.1,1.1,1.1))
par(mfrow=c(1,2))
par(las=1)
plot(x=tv.pvi$mean_pvi,y=tv.pvi$mean_share*100,
     pch=19,ylab="", xlab="",cex=tv.pvi$bin_n/10,
     col=adjustcolor("steelblue4",alpha.f=.8),main="",
     xaxt="n",xlim=c(-41,0),ylim=c(0,40))
abline(reg.line,col="darkblue",lwd=3)
lines(loess.smooth(y=dld.tv[dld.tv$year==2012,"share_tot_ad"]*100,
                   x=dld.tv$abs_pvi[dld.tv$year==2012],family="gaussian"),
      col="darkred",lwd=3,lty=2)
# draw an axis on the left 
axis(1,at=seq(-40,0,10), labels=c("90/10","80/20","70/30","60/40","50/50"))
mtext("TV Ads as Share of Campaign Expenditures (%)",side=2,line=3,cex=1,las=3)
mtext("PVI Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Less Competitive           More Competitive" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)

plot(x=tv.mar$mean_margin,y=tv.mar$mean_share*100,
     pch=19, ylab="", xlab="",cex=tv.pvi$bin_n/10,
     col=adjustcolor("steelblue4",alpha.f=.8),main="",
     xaxt="n",xlim=c(-41,0),ylim=c(0,40))
abline(reg.line,col="darkblue",lwd=3)
lines(loess.smooth(y=dld.tv[dld.tv$year==2012,"share_tot_ad"]*100,
                   x=dld.tv$margin_of_victory[dld.tv$year==2012],family="gaussian"),
      col="darkred",lwd=3,lty=2)
# draw an axis on the left 
axis(1,at=seq(-40,0,10), labels=c("90/10","80/20","70/30","60/40","50/50"))
mtext("TV Ads as Share of Campaign Expenditures (%)",side=2,line=3,cex=1,las=3)
mtext("Ex Post Competitiveness",side=1,line=2.5,cex=1)
arrow.labels <- expression(paste("" %<-% "Less Competitive          More Competitive" %->% ""))
mtext(arrow.labels,side=1,line=3.5,cex=.9)
graphics.off()

### campaign contact
raw.contact <- as.matrix(read.table("tables/cces_contact_all.txt",sep="\t", header=F))

pvi.any <- c("Any Contact", raw.contact[3,2], unlist(strsplit(raw.contact[4,2],","))[1],
             unlist(strsplit(raw.contact[4,2],"[,]"))[2])
ex.any <- c("Any Contact", raw.contact[5,3], unlist(strsplit(raw.contact[6,3],","))[1],
             unlist(strsplit(raw.contact[6,3],"[,]"))[2])
pvi.person <- c("In-Person", raw.contact[3,4], unlist(strsplit(raw.contact[4,4],","))[1],
             unlist(strsplit(raw.contact[4,4],"[,]"))[2])
ex.person <- c("In-Person", raw.contact[5,5], unlist(strsplit(raw.contact[6,5],","))[1],
            unlist(strsplit(raw.contact[6,5],"[,]"))[2])
pvi.phone <- c("Phone", raw.contact[3,6], unlist(strsplit(raw.contact[4,6],","))[1],
                unlist(strsplit(raw.contact[4,6],"[,]"))[2])
ex.phone <- c("Phone", raw.contact[5,7], unlist(strsplit(raw.contact[6,7],","))[1],
               unlist(strsplit(raw.contact[6,7],"[,]"))[2])
pvi.email <- c("Email/Text", raw.contact[3,8], unlist(strsplit(raw.contact[4,8],","))[1],
               unlist(strsplit(raw.contact[4,8],"[,]"))[2])
ex.email <- c("Email/Text", raw.contact[5,9], unlist(strsplit(raw.contact[6,9],","))[1],
              unlist(strsplit(raw.contact[6,9],"[,]"))[2])
pvi.mail <- c("Mail/Postcard", raw.contact[3,10], unlist(strsplit(raw.contact[4,10],","))[1],
               unlist(strsplit(raw.contact[4,10],"[,]"))[2])
ex.mail <- c("Mail/Postcard", raw.contact[5,11], unlist(strsplit(raw.contact[6,11],","))[1],
              unlist(strsplit(raw.contact[6,11],"[,]"))[2])

pvi.pts <- as.numeric(c(pvi.any[2],pvi.person[2],pvi.phone[2],pvi.email[2],pvi.mail[2]))*1000
ex.pts <- as.numeric(c(ex.any[2],ex.person[2],ex.phone[2],ex.email[2],ex.mail[2]))*1000
pvi.lb <- as.numeric(c(pvi.any[3],pvi.person[3],pvi.phone[3],pvi.email[3],pvi.mail[3]))*1000
ex.lb <- as.numeric(c(ex.any[3],ex.person[3],ex.phone[3],ex.email[3],ex.mail[3]))*1000
pvi.ub <- as.numeric(c(pvi.any[4],pvi.person[4],pvi.phone[4],pvi.email[4],pvi.mail[4]))*1000
ex.ub <- as.numeric(c(ex.any[4],ex.person[4],ex.phone[4],ex.email[4],ex.mail[4]))*1000

#***FIG9***

par(mfrow=c(1,1))
#pdf("figures/mfx_contact.pdf",width = 8, height=6)
jpeg("figures/mfx_contact.jpeg",res=300,width = 8, height=6, units="in")

par(mar=c(5.1,4.1,1.1,1.1))
par(las=1)
plot(0,xaxt='n',pch="",xlab="", ylab="", xlim=c(.5,5.5), ylim=c(-7,10.5))
points(x=1:5-.1,y=pvi.pts, pch=15, col="steelblue2", cex=1.2)
points(x=1:5+.1,y=ex.pts, pch=19, col="darkblue", cex=1.2)
abline(h=0,col="black",lwd=2,lty=1)
segments(x0=1:5-.1,y0=pvi.lb,y1=pvi.ub, lwd=2.5, col="steelblue2")
segments(x0=1:5+.1,y0=ex.lb,y1=ex.ub, lwd=2.5, col="darkblue")
axis(1,at=seq(1,5,1), labels=c("Any Contact","In-Person","Phone","Email/Text","Mail/Postcard"))
mtext("Contact (%)",side=2,line=2.5,cex=1,las=3)
mtext("Method of Contact",side=1,line=2.5,cex=1)
mtext((expression("PVI Competitiveness Specification" * phantom(" | Ex-Post Competitiveness Specification"))),
      col="steelblue2",side=1,line=4)
mtext((expression(phantom("PVI Competitiveness Specification |") * " Ex-Post Competitiveness Specification")),
      col="darkblue",side=1,line=4)
mtext((expression(phantom("PVI Competitiveness Specification ") * "|" * phantom(" Ex-Post Competitiveness Specification"))),
      col="black",side=1,line=4)
graphics.off()
